# (c) Copyright 2016 Hewlett Packard Enterprise Development LP
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed
# under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
# CONDITIONS OF ANY KIND, either express or implied. See the License for the
# specific language governing permissions and limitations under the License.

thaigo_client = {
  url: 'https://172.16.101.144/',
  user: 'Administrator',
  password: 'rainforest',
  api_version: 200,
  ssl_enabled: false
}

# :none
oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
end

oneview_logical_interconnect 'Remove Encl 1, interconnect 1' do
  client thaigo_client
  enclosure 'Encl1'
  bay_number 1
  action :remove_interconnect
end

oneview_logical_interconnect 'Add Encl 1, interconnect 1' do
  client thaigo_client
  enclosure 'Encl1'
  bay_number 1
  action :add_interconnect
end

oneview_ethernet_network 'ChefEthernet1301' do
  client thaigo_client
  data(
    vlanId:  '1301',
    purpose:  'General',
    smartLink:  false,
    privateNetwork:  false
  )
end

oneview_ethernet_network 'ChefEthernet1302' do
  client thaigo_client
  data(
    vlanId:  '1302',
    purpose:  'General',
    smartLink:  false,
    privateNetwork:  false
  )
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  internal_networks ['ChefEthernet1301', 'ChefEthernet1302']
  action :update_internal_networks
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'ethernetSettings' => {
      'igmpIdleTimeoutInterval' => 230,
      'macRefreshInterval' => 15
    }
  )
  action :update_ethernet_settings
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'portMonitor' => {
      'enabled' => true
    }
  )
  action :update_port_monitor
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'qosConfiguration' => {
      'activeQosConfig' => {
        'configType' => 'Passthrough',
        'description' => 'Created using chef-oneview'
      }
    }
  )
  action :update_qos_configuration
end



oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'telemetryConfiguration' => {
      'sampleCount' => 25,
      'sampleInterval' => 225
    }
  )
  action :update_telemetry_configuration
end

# Adds one SNMP Trap configuration
oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'snmpConfiguration' => {
      'snmpAccess' => ['172.18.6.15/24']
    }
  )
  trap_destinations(
    '172.18.6.16' => {
      'trapFormat' => 'SNMPv1',
      'communityString' => 'public',
      'severities' => ['Critical', 'Major', 'Unknown'],
      'vcmTraps' => ['Legacy'],
      'enetTraps' => ['PortStatus', 'PortThresholds'],
      'fcTraps' => ['Other']
    }
  )
  action :update_snmp_configuration
end

# Cleans the SNMP Traps
oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  data(
    'snmpConfiguration' => {
      'snmpAccess' => []
    }
  )
  action :update_snmp_configuration
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  firmware 'Online ROM Flash for Linux - Power Management Controller'
  firmware_data(
    ethernetActivationDelay: 10,
    ethernetActivationType: 'OddEven',
    fcActivationDelay: 10,
    fcActivationType: 'Serial',
    force: true
  )
  action :stage_firmware
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  action :reapply_configuration
end

oneview_logical_interconnect 'Encl1-CHEF_LIG_01' do
  client thaigo_client
  action :update_from_group
end
